@@ -1,7 +1,13 @@
-import model
+import pyosm.model as model
 import datetime
-import urllib2
-import StringIO
+try:
+    import urllib.request as urllib2
+except ImportError:
+    import urllib2
+try:
+    import StringIO
+except ImportError:
+    from io import StringIO
 import gzip
 import time
 import os.path
@@ -29,13 +35,7 @@ def maybeFloat(s):
     return float(s) if s is not None else s
 
 def maybeBool(s):
-    if s is not None:
-        if s == 'true':
-            return True
-        else:
-            return False
-    else:
-        return s
+    return s == 'true' if s is not None else s
 
 def readState(state_file, sep='='):
     state = {}
@@ -50,7 +50,7 @@ def readState(state_file, sep='='):
 
     return state
 
-def iter_changeset_stream(start_sqn=None, base_url='http://planet.openstreetmap.org/replication/changesets', expected_interval=60, parse_timestamps=True, state_dir=None):
+def iter_changeset_stream(start_sqn=None, base_url='https://planet.openstreetmap.org/replication/changesets', expected_interval=60, parse_timestamps=True, state_dir=None):
     """Start processing an OSM changeset stream and yield one (action, primitive) tuple
     at a time to the caller."""
 
@@ -89,7 +89,7 @@ def iter_changeset_stream(start_sqn=None, base_url='http://planet.openstreetmap.
                 gzipper = gzip.GzipFile(fileobj=content)
                 interval_fudge -= (interval_fudge / 2.0)
                 break
-            except urllib2.HTTPError, e:
+            except urllib2.HTTPError as e:
                 if e.code == 404:
                     time.sleep(delay)
                     delay = min(delay * 2, 13)
@@ -210,40 +210,7 @@ def iter_osm_change_file(f, parse_timestamps=True):
         while elem.getprevious() is not None:
             del elem.getparent()[0]
 
-def iter_realtime_osm_stream(start_sqn=None, base_url='http://planet.openstreetmap.org/replication/streaming', parse_timestamps=True, state_dir=None):
-    # If the user specifies a state_dir, read the state from the statefile there
-    if state_dir:
-        if not os.path.exists(state_dir):
-            raise Exception('Specified state_dir "%s" doesn\'t exist.' % state_dir)
-
-        if os.path.exists('%s/realtime_state.txt' % state_dir):
-            with open('%s/realtime_state.txt' % state_dir) as f:
-                state = readState(f)
-                start_sqn = state['sequenceNumber']
-
-    url = '%s/replicationData/%s/tail' % (base_url, start_sqn)
-    content = urllib2.urlopen(url)
-
-    while True:
-        # Format is described here http://wiki.openstreetmap.org/wiki/Osmosis/Replication#Streaming_Replication_Wire_Protocol
-        state_size = int(content.readline().strip())
-        state_data = content.read(state_size)
-        state = readState(state_data.strip().split('\n'))
-
-        diff_size = int(content.readline().strip())
-        diff_data = gzip.GzipFile(fileobj=StringIO.StringIO(content.read(diff_size)))
-
-        for a in iter_osm_change_file(diff_data, parse_timestamps):
-            yield a
-
-        stateTs = datetime.datetime.strptime(state['timestamp'], "%Y-%m-%dT%H:%M:%SZ")
-        yield (None, model.Finished(state['sequenceNumber'], stateTs))
-
-        if state_dir:
-            with open('%s/realtime_state.txt' % state_dir, 'w') as f:
-                f.write(state_data)
-
-def iter_osm_stream(start_sqn=None, base_url='http://planet.openstreetmap.org/replication/minute', expected_interval=60, parse_timestamps=True, state_dir=None):
+def iter_osm_stream(start_sqn=None, base_url='https://planet.openstreetmap.org/replication/minute', expected_interval=60, parse_timestamps=True, state_dir=None):
     """Start processing an OSM diff stream and yield one changeset at a time to
     the caller."""
 
@@ -298,7 +265,7 @@ def iter_osm_stream(start_sqn=None, base_url='http://planet.openstreetmap.org/re
                 u = urllib2.urlopen(url)
                 interval_fudge -= (interval_fudge / 2.0)
                 break
-            except urllib2.HTTPError, e:
+            except urllib2.HTTPError as e:
                 if e.code == 404:
                     time.sleep(delay)
                     delay = min(delay * 2, 13)
@@ -425,7 +392,7 @@ def parse_osm_file(f, parse_timestamps=True):
     return (nodes, ways, relations)
 
 def get_note(note_id, parse_timestamps=True):
-    u = urllib2.urlopen('http://www.openstreetmap.org/api/0.6/notes/%d' % note_id)
+    u = urllib2.urlopen('https://www.openstreetmap.org/api/0.6/notes/%d' % note_id)
     tree = etree.parse(u)
     note_elem = tree.xpath('/osm/note')[0]
 
@@ -461,7 +428,7 @@ def iter_osm_notes(feed_limit=25, interval=60, parse_timestamps=True):
 
     last_seen_guid = None
     while True:
-        u = urllib2.urlopen('http://www.openstreetmap.org/api/0.6/notes/feed?limit=%d' % feed_limit)
+        u = urllib2.urlopen('https://www.openstreetmap.org/api/0.6/notes/feed?limit=%d' % feed_limit)
 
         tree = etree.parse(u)
 
